static char rcsid[] = "@(#)$Id: sendcmd.c,v 1.6 2013-12-15 18:31:52 hurtta Exp $";

/******************************************************************************
 *  The Elm (ME+) Mail System  -  $Revision: 1.6 $   $State: Exp $
 *
 *  Author: Kari Hurtta <hurtta+elm@siilo.FMI.FI>
 *      or  Kari Hurtta <elm@elmme-mailer.org>
 *****************************************************************************/

#include "def_command.h"
#include "s_command.h"
#include "patchlevel.h"

DEBUG_VAR(Debug,__FILE__,"command");


/* increment refcount */
struct elm_commands *give_send_commands() 
{        

    static struct elm_commands  * send_commands = NULL;
    struct elm_commands  * ret = NULL;

    if (send_commands) {
	inc_commands_refcount(send_commands);
	return send_commands;
    }
    
    ret =  new_commands(format_string(CATGETS(elm_msg_cat, CommandSet,
					      CommandSendKeyTitle,"Send command")),
			format_string(CATGETS(elm_msg_cat, CommandSet,
					      CommandSendDescTitle,
					      "Elm %s PL%s Action"),
				      VERSION,PATCHLEVEL),
			&send_commands);


    /* TODO? center */
    add_commands_title(ret,pg_BOLD,CATGETS(elm_msg_cat, CommandSet,
					   CommandSendTitle1,
					   "            Commands available from the Mail Pre-Send Screen in Elm %s"),
		       VERSION);

    {
	int cmds[] = { '\n','\r',  0 };
	
	add_commands_help_many(ret,0, cmds,
			       CATGETS(elm_msg_cat, CommandSet, CommandSendDefaultAction,
				       "Default action"));
    }


    add_commands_help_single(ret,NULL,0,'?',
			     CATGETS(elm_msg_cat, CommandSet, CommandCommonCommandHelp,
				     "Show command help or this screen of information."));

    add_commands_help_single(ret,NULL,0,'a',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendAttachments,
				     "Add attachments to message or view attachments."));

    {
	int cmds[] = { 'b','B',  0 };

	add_commands_help_many(ret,0,cmds,
			       CATGETS(elm_msg_cat, CommandSet, CommandSendBcc,
				       "Edit Bcc header field of message."));
    }


    {
	int cmds[] = { 'c','C',  0 };

	add_commands_help_many(ret,0,cmds,
			       CATGETS(elm_msg_cat, CommandSet, CommandSendCc,
				       "Edit Cc header field of message."));
    }


    add_commands_help_single(ret,NULL,0,'D',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendDsnSettings,
				     "View or set delivery notification settings of message."));
    
    
    add_commands_help_single(ret,NULL,0,ctrl('D'),
			     CATGETS(elm_msg_cat, CommandSet, CommandSendDsnToggle,
				     "Toggle delivery notification setting of message."));

    add_commands_help_single(ret,NULL,0,'e',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendEditMessage,
				     "Edit message text."));
    
    {
	int cmds[] = { 'f',*def_ans_no,  0 };

	add_commands_help_many(ret,0, cmds,
			       CATGETS(elm_msg_cat, CommandSet, CommandSendForget,
				       "Forget message."));
    }

#if defined(USE_PGP) || defined(REMOTE_MBX)
    add_commands_help_single(ret,NULL,0,ctrl('F'),
			     CATGETS(elm_msg_cat, CommandSet, CommandCommonForgetPassphrase,
				     "Forget PGP passphrase and close cached connections."));
#endif

    add_commands_help_single(ret,NULL,0,'h',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendHeaders,
				     "View or set header fields of message."));

#ifdef ISPELL
    add_commands_help_single(ret,NULL,0,'i',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendIspell,
				     "Pass message to ispell."));

#endif

#ifdef USE_PGP
    add_commands_help_single(ret,NULL,0,'P',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendPgp,
				     "Sign or encrypt message with PGP."));
#endif

    add_commands_help_single(ret,NULL,0,'p',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendCopy,
				     "Set copy file/folder target for message."));

    add_commands_help_single(ret,NULL,0,'R',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendReturnPath,
				     "Edit Return-Path of message."));


    {
	int cmds[] = { 's','S',  0 };

	add_commands_help_many(ret,0,cmds,
			       CATGETS(elm_msg_cat, CommandSet, CommandSendSubject,
				       "Edit Subject of message."));
    }



    {
	int cmds[] = { 't','T',  0 };

	add_commands_help_many(ret,0,cmds,
			       CATGETS(elm_msg_cat, CommandSet, CommandSendTo,
				       "Edit To header field of message."));
    }

    add_commands_help_single(ret,NULL,0,'w',
			     CATGETS(elm_msg_cat, CommandSet, CommandSendViewFolder,
				     "View current folder."));

    add_commands_help_single(ret,NULL,0,*def_ans_yes,
			     CATGETS(elm_msg_cat, CommandSet, CommandSendMessage,
				     "Send message."));
    
    DPRINT(Debug,30,(&Debug,
		     "give_send_commands=%p [pointer %p]\n",
		     ret,&send_commands));

    return ret;
}



/*
 * Local Variables:
 *  mode:c
 *  c-basic-offset:4
 *  buffer-file-coding-system: iso-8859-1
 * End:
 */
